BASE_URL = "https://jarvisai.in/"
USER_CONFIG_FOLDER = './user_configs/'
API_KEY_PATH = f'{USER_CONFIG_FOLDER}api_key.txt'
SPEECH_ENGINE_PATH = f'{USER_CONFIG_FOLDER}speech_engine.txt'
API_AUTH_URL = f"{BASE_URL}check_secret_key?secret_key="


class Constant:
    def __init__(self):
        self.BASE_URL = BASE_URL
        self.USER_CONFIG_FOLDER = USER_CONFIG_FOLDER
        self.API_KEY_PATH = API_KEY_PATH
        self.SPEECH_ENGINE_PATH = SPEECH_ENGINE_PATH
        self.API_AUTH_URL = API_AUTH_URL




import pywhatkit as kit


def yt_play(inp_command, *arg, **kwargs):
    kit.playonyt(inp_command)
    return "Playing Video on Youtube"


if __name__ == "__main__":
    yt_play('play on youtube shape of you')



import requests
import pycountry


def check_command_is_for_covid_cases(command):
    try:
        command = command.title()
        country = get_country(command)
        cases = get_covid_cases(country)
        return f"The current active cases in {country} are {cases}"
    except Exception as e:
        print("Error: ", e)
        return "Sorry, I couldn't find the country you are looking for. Or server is down."


def get_country(command):  # For getting only the country name for the whole query
    for country in pycountry.countries:
        if country.name in command:
            return country.name


def get_covid_cases(country):  # For getting current covid cases
    totalActiveCases = 0
    response = requests.get('https://api.covid19api.com/live/country/' + country + '/status/confirmed').json()
    for data in response:
        totalActiveCases += data.get('Active')
    return totalActiveCases


if __name__ == '__main__':
    print(check_command_is_for_covid_cases('active Covid India cases?'))  # Example



from pprint import pprint
import textdistance
import requests
try:
    from CONSTANT import Constant
except:
    from JarvisAI.CONSTANT import Constant


CONSTANT = Constant()


def make_decision_nlp(string, classes, secret_key=None):
    try:
        answer = []
        answer_ = {}
        answer_li = []
        for clas in classes.split(","):
            acc = textdistance.jaccard(string, clas)
            answer_li.append({'label': clas, 'confidence': acc})
            answer.append({'label': clas.strip(), 'confidence': acc})
            answer_[clas] = acc
        response = dict()
        response["data"] = [{'label': max(answer_, key=answer_.get).strip(),
                             'confidences': answer}]
        best = response["data"][0]["label"]
        return best
    except Exception as e:
        print(e)
        return None


def make_decision_ai(secret_key, string, classes):
    try:
        url = f'{CONSTANT.BASE_URL}make_decision_ktrain_api?secret_key={secret_key}'
        r = requests.post(url, json={'string': string,
                                     'classes': classes})
        res = r.json()
        res = res['action'], None
    except Exception as e:
        print(e)
        res = None
    return res


def make_decision_jarvisai(secret_key, string):
    try:
        url = f'{CONSTANT.BASE_URL}make_decision_intent_classifier?secret_key={secret_key}&string={string}'
        r = requests.get(url)
        res = r.json()
        res = res['action']['data'][0]['class'], res['action']['data'][0]['accuracy']
    except Exception as e:
        print(e)
        res = None
    return res


def make_decision_jarvisai_string_matching(classes_list, input_string):
    try:
        answer = []
        answer_ = {}
        answer_li = []
        for clas in classes_list:
            acc = textdistance.jaccard(input_string, clas)
            answer_li.append({'label': clas, 'confidence': acc})
            answer.append({'label': clas.strip(), 'confidence': acc})
            answer_[clas] = acc
        response = dict()
        response["data"] = [{'label': max(answer_, key=answer_.get).strip(),
                             'confidences': answer}]
        best = response["data"][0]["label"]
        print("Best", best)
        print("Res", response)
        return best
    except Exception as e:
        print(e)
        return None


if __name__ == "__main__":
    inp = "date"
    clss = "asking date, asking time, tell me joke, tell me news, tell me weather, tell me about, open website, play on youtube, send whatsapp message, send email"
    # pprint(make_decision_nlp(inp, clss))
    # pprint(make_decision_ai(inp, clss))
    pprint(make_decision_ai('ddcb247ce8b4c56684c83e4f97971af8', inp, clss))
    pprint(make_decision_jarvisai('ddcb247ce8b4c56684c83e4f97971af8', inp))



import pyjokes


def tell_me_joke(inp_command=None, lang='en', cat='neutral'):
    """
    Function to tell a joke
    Read https://pyjok.es/api/ for more details
    :param inp_command: input command
    :param lang: str
    :param cat: str
    :return: str
    """
    return pyjokes.get_joke(language=lang, category=cat)


if __name__ == '__main__':
    print(tell_me_joke())



import pyscreenshot
import os
import datetime


def take_screenshot(inp_command):
    try:
        image = pyscreenshot.grab()
        image.show()
        a = datetime.datetime.now()
        if not os.path.exists("screenshot"):
            os.mkdir("screenshot")
        image.save(f"screenshot/{a.day, a.month, a.year}_screenshot.png")
        print(f"Screenshot taken: screenshot/{a.day, a.month, a.year}_screenshot.png ")
        return f"Screenshot taken"
    except Exception as e:
        print(e)
        return "Unable to take screenshot"


if __name__ == "__main__":
    take_screenshot()



import pywhatkit as kit


def send_whatsapp_message(inp_command, *arg, **kwargs):
    country_code = input("Enter country code (Default=+91): ") or "+91"
    number = input("Enter whatsapp number: ")
    message = input("Enter message: ")
    print("Sending message...")
    kit.sendwhatmsg_instantly(f"{country_code}{number}", message, wait_time=20)
    print("Message sent successfully!")


if __name__ == "__main__":
    send_whatsapp_message()



import requests
import spacy

try:
    nlp = spacy.load('en_core_web_sm')
except Exception as e:
    print(e)
    print(str(e).split('.')[0] + ". Please wait while we download the model")
    import os

    os.system('python -m spacy download en_core_web_sm')
    nlp = spacy.load('en_core_web_sm')


def get_temperature(json_data):
    temp_in_celcius = json_data['main']['temp']
    return temp_in_celcius


def get_weather_type(json_data):
    weather_type = json_data['weather'][0]['description']
    return weather_type


def get_wind_speed(json_data):
    wind_speed = json_data['wind']['speed']
    return wind_speed


def get_weather_data(json_data, city):
    weather_type = get_weather_type(json_data)
    temperature = get_temperature(json_data)
    wind_speed = get_wind_speed(json_data)
    weather_details = ''
    return weather_details + (
        "The weather in {} is currently {} with a temperature of {} degrees and wind speeds reaching {} km/ph".format(
            city, weather_type, temperature, wind_speed))


def main_weather(city):
    """
    City to weather
    :param city: City
    :return: weather
    """
    api_address = f'https://api.openweathermap.org/data/2.5/weather?q={city}&appid=a10fd8a212e47edf8d946f26fb4cdef8&q='
    units_format = "&units=metric"
    final_url = api_address + city + units_format
    json_data = requests.get(final_url).json()
    if json_data['cod'] == 200:
        return get_weather_data(json_data, city)
    else:
        return "I am sorry, I could not find the weather for {}".format(city) + ".\nError code: {}".format(
            json_data['message'])


def weather_app(city):
    weather_res = main_weather(city)
    return weather_res


def get_weather(inp_command, *args, **kwargs):
    doc = nlp(inp_command)
    city = None
    for ent in doc.ents:
        city = ent.text

    if city is not None:
        return weather_app(city)
    else:
        url = 'http://ipinfo.io/json'
        response = requests.get(url)
        data = response.json()
        city = data.get('city')
        return weather_app(city)


if __name__ == "__main__":
    print(get_weather('what is the temperature in Tokyo?'))



import speech_recognition as sr
import pyaudio
import wave
import googletrans


def record_audio(duration=5):
    filename = "recording.wav"
    # set the chunk size of 1024 samples
    chunk = 1024
    # sample format
    FORMAT = pyaudio.paInt16
    # mono, change to 2 if you want stereo
    channels = 1
    # 44100 samples per second
    sample_rate = 44100
    record_seconds = duration
    # initialize PyAudio object
    p = pyaudio.PyAudio()
    # open stream object as input & output
    stream = p.open(format=FORMAT,
                    channels=channels,
                    rate=sample_rate,
                    input=True,
                    output=True,
                    frames_per_buffer=chunk)
    frames = []
    for i in range(int(sample_rate / chunk * record_seconds)):
        data = stream.read(chunk)
        # if you want to hear your voice while recording
        # stream.write(data)
        frames.append(data)
    # print("Finished recording.")
    # stop and close stream
    stream.stop_stream()
    stream.close()
    # terminate pyaudio object
    p.terminate()
    # save audio file
    # open the file in 'write bytes' mode
    wf = wave.open(filename, "wb")
    # set the channels
    wf.setnchannels(channels)
    # set the sample format
    wf.setsampwidth(p.get_sample_size(FORMAT))
    # set the sample rate
    wf.setframerate(sample_rate)
    # write the frames as bytes
    wf.writeframes(b"".join(frames))
    # close the file
    wf.close()


def speech_to_text_google(input_lang='en', key=None, duration=5):
    try:
        record_audio(duration=duration)
        r = sr.Recognizer()
        with sr.AudioFile("recording.wav") as source:
            audio = r.record(source)
            command = r.recognize_google(audio, language=input_lang, key=key)
        # TODO: Translate command to target language
        # if input_lang != 'en':
        #     translator = googletrans.Translator()
        #     command = translator.translate("command", dest='hi').text
        return command, True
    except Exception as e:
        print(e)
        return e, False


if __name__ == "__main__":
    print(speech_to_text_google())



import shutup

shutup.please()
from transformers import logging

logging.set_verbosity_error()

from transformers import AutoTokenizer, AutoModel
from torch.nn import functional as F

tokenizer = AutoTokenizer.from_pretrained('deepset/sentence_bert')
model = AutoModel.from_pretrained('deepset/sentence_bert')


def make_decision(classes_list, input_string):
    # classes = "'" + "', '".join(classes_list) + "'"
    sentence = '"' + input_string + '" in which class this belongs to out of following'
    labels = classes_list

    # run inputs through model and mean-pool over the sequence
    # dimension to get sequence-level representations
    inputs = tokenizer.batch_encode_plus([sentence] + labels,
                                         return_tensors='pt',
                                         pad_to_max_length=True)
    input_ids = inputs['input_ids']
    attention_mask = inputs['attention_mask']
    output = model(input_ids, attention_mask=attention_mask)[0]
    sentence_rep = output[:1].mean(dim=1)
    label_reps = output[1:].mean(dim=1)

    # now find the labels with the highest cosine similarities to
    # the sentence
    similarities = F.cosine_similarity(sentence_rep, label_reps)
    closest = similarities.argsort(descending=True)
    for ind in closest:
        # print(f'label: {labels[ind]} \t similarity: {similarities[ind]}')
        break
    return labels[ind]


if __name__ == "__main__":
    ans = make_decision(
        ['asking date', 'asking time', 'tell me joke', 'tell me news', 'asking weather', 'tell me about',
         'open website', 'play on youtube', 'send whatsapp message', 'send email',
         'greet and hello hi kind of things, general check in', 'goodbye', 'take screenshot', 'click photo',
         'download youtube video', 'covid cases', 'play games', 'places near me', 'i am bored', 'volume control'],
        "'how are you' in which class this belongs to out of following")

    print(ans)
